tlslite.messages.ServerHello

Package tlslite :: Module messages :: Class ServerHello |
[show private | hide private]
[frames | no frames]

## Class ServerHello

         Msg --+
               |
    HandshakeMsg --+
                   |
                  ServerHello

Method Summary
| `__init__(self)`
| `create(self, version, random, session_id, cipher_suite, certificate_type)`
| `parse(self, p)`
| `write(self, trial)`
Inherited from HandshakeMsg
| ``preWrite`(self, handshakeType, trial)`
Inherited from Msg
| ``postWrite`(self, w, trial)`

Generated by Epydoc 2.0 on Mon Feb 21 21:56:55 2005 | http://epydoc.sf.net